// Deshabilitar Dropzone.autoDiscover ANTES de que se cargue el DOM
Dropzone.autoDiscover = false;

// Variables globales
let uploadedImageNames = [];
let pdfFileName = null;
let autocadFileName = null;
let productId = null;
let existingImages = [];
let producto_imagen_principal = null;

/**
 * Función para mostrar mensajes de depuración en consola
 */
function debug(titulo, mensaje, data = null) {
    console.log(`📌 ${titulo}:`, mensaje, data || '');
}

/**
 * Inicialización cuando el DOM está completamente cargado
 */
document.addEventListener('DOMContentLoaded', function () {
    // Obtener ID del producto de la URL
    const urlParams = new URLSearchParams(window.location.search);
    productId = urlParams.get('id');

    if (!productId) {
        mostrarErrorYRedirigir('No se especificó un ID de producto válido', 'productos.php');
        return;
    }

    // Inicializar componentes
    initDropzones();
    loadSubcategorias();
    setupTranslation();
    loadProductData(productId);

    // Configurar eventos de botones principales
    configurarBotonesForm();

    // Prevenir envío de formulario con Enter
    prevenirEnvioConEnter();

    // Configurar Summernote para la descripción
    configurarSummernote();

    // Iniciar tooltips de Bootstrap
    iniciarTooltips();
});

/**
 * Muestra un error y redirige a una página específica
 * @param {string} mensaje - Mensaje de error a mostrar
 * @param {string} ruta - Ruta a la que redirigir después de mostrar el error
 */
function mostrarErrorYRedirigir(mensaje, ruta) {
    Swal.fire({
        icon: 'error',
        title: 'Error',
        text: mensaje,
        allowOutsideClick: false
    }).then(() => {
        window.location.href = ruta;
    });
}

/**
 * Configura los botones del formulario (guardar y cancelar)
 */
function configurarBotonesForm() {
    document.getElementById('guardar').addEventListener('click', updateProducto);
    document.getElementById('cancelar').addEventListener('click', function (e) {
        e.preventDefault();
        window.location.href = "productos.php";
    });
}

/**
 * Evita que el formulario se envíe al presionar Enter
 */
function prevenirEnvioConEnter() {
    document.querySelectorAll('#productoForm input, #productoForm select, #productoForm textarea').forEach(function (element) {
        element.addEventListener('keydown', function (event) {
            if (event.key === 'Enter') {
                event.preventDefault();
            }
        });
    });
}

/**
 * Configura los editores Summernote para las descripciones
 */
function configurarSummernote() {
    $('#descripcion_es, #descripcion_en').summernote({
        height: 150,
        disableDragAndDrop: true,
        toolbar: [
            ['style', ['style']],
            ['font', ['bold', 'italic', 'underline', 'clear']],
            ['fontname', ['fontname']],
            ['color', ['color']],
            ['para', ['ul', 'ol', 'paragraph']]
        ],
        callbacks: {
            onImageUpload: function () {
                Swal.fire({
                    icon: "error",
                    title: "Error",
                    text: "No se permite subir imágenes en este campo.",
                    showCancelButton: false,
                    showConfirmButton: false,
                    timer: 1500
                });
            }
        }
    });
}

/**
 * Inicia los tooltips de Bootstrap
 */
function iniciarTooltips() {
    var tooltipTriggerList = [].slice.call(document.querySelectorAll('[data-bs-toggle="tooltip"]'));
    tooltipTriggerList.map(function (tooltipTriggerEl) {
        return new bootstrap.Tooltip(tooltipTriggerEl);
    });
}

/**
 * Carga los datos del producto desde el servidor
 * @param {string} productId - ID del producto a cargar
 */
function loadProductData(productId) {
    $.ajax({
        url: 'database/model/productos.php',
        type: 'POST',
        data: {
            "action": "getProducto",
            "id": productId
        },
        success: function (response) {
            try {
                const producto = JSON.parse(response);

                if (producto.status === 'error') {
                    mostrarErrorYRedirigir(producto.message || 'No se pudo cargar el producto', 'productos.php');
                    return;
                }

                console.log("Producto cargado:", producto);

                // Rellenar datos básicos
                rellenarDatosBasicos(producto);

                // Cargar archivos adjuntos
                cargarDocumentosPDF(producto);
                cargarArchivosAutocad(producto);
                cargarImagenesProducto(producto);

                // Agregar input oculto con el ID del producto
                agregarCampoIdProducto(productId);

            } catch (e) {
                console.error("Error al procesar la respuesta:", e);
                Swal.fire({
                    icon: 'error',
                    title: 'Error',
                    text: 'Error al cargar los datos del producto'
                });
            }
        },
        error: function (xhr, status, error) {
            console.error("Error AJAX:", error);
            Swal.fire({
                icon: 'error',
                title: 'Error',
                text: 'Error de conexión al servidor'
            });
        }
    });
}

/**
 * Rellena los campos básicos del formulario con los datos del producto
 * @param {Object} producto - Objeto con los datos del producto
 */
function rellenarDatosBasicos(producto) {
    document.getElementById('nombre_es').value = producto.nombre_es || '';
    document.getElementById('nombre_en').value = producto.nombre_en || '';
    document.getElementById('sku').value = producto.sku || '';

    // Seleccionar subcategoría cuando estén cargadas (puede ser asíncrono)
    const selectSubcategoria = document.getElementById('id_subcategoria');
    const checkSubcategoria = setInterval(() => {
        if (selectSubcategoria.options.length > 1) {
            clearInterval(checkSubcategoria);
            selectSubcategoria.value = producto.id_subcategoria || '';
        }
    }, 100);

    // Checkbox destacado
    document.getElementById('destacado').checked = producto.destacado == 1;

    // Descripción en Summernote
    if (producto.descripcion_es) {
        $('#descripcion_es').summernote('code', producto.descripcion_es);
    }
    if (producto.descripcion_en) {
        $('#descripcion_en').summernote('code', producto.descripcion_en);
    }
}

/**
 * Carga y muestra el PDF asociado al producto
 * @param {Object} producto - Objeto con los datos del producto
 */
function cargarDocumentosPDF(producto) {
    if (producto.pdf && producto.pdf.trim() !== '') {
        console.log("PDF encontrado:", producto.pdf);
        pdfFileName = producto.pdf;
        document.getElementById('pdf').value = pdfFileName;

        // Mostrar el archivo PDF actual
        const pdfDropzone = Dropzone.forElement("#pdfForm");
        if (pdfDropzone) {
            // Crear un archivo falso para mostrar en la interfaz
            const mockFile = { name: pdfFileName, size: 12345, accepted: true };
            pdfDropzone.emit("addedfile", mockFile);
            pdfDropzone.emit("complete", mockFile);

            // Crear previsualización personalizada
            const pdfPreview = document.createElement('div');
            pdfPreview.className = 'pdf-preview mt-3 p-3 border rounded';

            const fileInfo = document.createElement('div');
            fileInfo.className = 'd-flex align-items-center';

            const icon = document.createElement('i');
            icon.className = 'fas fa-file-pdf text-danger me-2 fa-2x';

            const fileName = document.createElement('span');
            fileName.textContent = pdfFileName;
            fileName.className = 'flex-grow-1 span-pdf';

            // Botones: eliminar y descargar
            const buttonGroup = document.createElement('div');
            buttonGroup.className = 'd-flex';

            const downloadBtn = document.createElement('a');
            downloadBtn.href = `pdf/productos/${pdfFileName}`;
            downloadBtn.target = '_blank';
            downloadBtn.className = 'btn btn-sm btn-primary me-2';
            downloadBtn.textContent = 'Ver';

            const removeBtn = document.createElement('button');
            removeBtn.className = 'btn btn-sm btn-danger';
            removeBtn.textContent = 'Eliminar';
            removeBtn.addEventListener('click', function () {
                pdfDropzone.removeFile(mockFile);
            });

            // Ensamblar elementos
            buttonGroup.appendChild(downloadBtn);
            buttonGroup.appendChild(removeBtn);

            fileInfo.appendChild(icon);
            fileInfo.appendChild(fileName);
            fileInfo.appendChild(buttonGroup);
            pdfPreview.appendChild(fileInfo);

            // Agregar al DOM
            const pdfContainer = document.querySelector('#pdfForm').nextElementSibling;
            pdfContainer.innerHTML = ''; // Limpiar contenedor
            pdfContainer.appendChild(pdfPreview);

            // Guardar referencia al elemento para poder eliminarlo más tarde
            mockFile.previewElement = pdfPreview;
        }
    }
}

/**
 * Carga y muestra los archivos AutoCAD asociados al producto
 * @param {Object} producto - Objeto con los datos del producto
 */
function cargarArchivosAutocad(producto) {
    if (producto.autocard) {
        autocadFileName = producto.autocard;
        document.getElementById('autocard').value = autocadFileName;

        // Mostrar el archivo AutoCAD actual
        const autocadDropzone = Dropzone.forElement("#autocadForm");
        if (autocadDropzone) {
            // Crear un archivo falso para mostrar en la interfaz
            const mockFile = { name: autocadFileName, size: 12345, accepted: true };
            autocadDropzone.emit("addedfile", mockFile);
            autocadDropzone.emit("complete", mockFile);

            // Crear previsualización personalizada
            const autocadPreview = document.createElement('div');
            autocadPreview.className = 'autocad-preview mt-3 p-3 border rounded';

            const fileInfo = document.createElement('div');
            fileInfo.className = 'd-flex align-items-center';

            const icon = document.createElement('i');
            icon.className = 'fas fa-file-alt text-primary me-2 fa-2x';

            const fileName = document.createElement('span');
            fileName.textContent = autocadFileName;
            fileName.className = 'flex-grow-1 span-pdf';

            const removeBtn = document.createElement('button');
            removeBtn.className = 'btn btn-sm btn-danger ms-2';
            removeBtn.textContent = 'Eliminar';
            removeBtn.addEventListener('click', function () {
                autocadDropzone.removeFile(mockFile);
            });

            // Ensamblar elementos
            fileInfo.appendChild(icon);
            fileInfo.appendChild(fileName);
            fileInfo.appendChild(removeBtn);
            autocadPreview.appendChild(fileInfo);

            // Agregar al DOM
            document.querySelector('#autocadForm').nextElementSibling.appendChild(autocadPreview);

            // Guardar referencia al elemento para poder eliminarlo más tarde
            mockFile.previewElement = autocadPreview;
        }
    }
}

/**
 * Carga y muestra las imágenes asociadas al producto
 * @param {Object} producto - Objeto con los datos del producto
 */
function cargarImagenesProducto(producto) {
    console.log("Cargando imágenes del producto:", producto);

    // Crear input oculto si no existe
    if (!document.getElementById('imagenes')) {
        const imagenesInput = document.createElement('input');
        imagenesInput.type = 'hidden';
        imagenesInput.name = 'imagenes';
        imagenesInput.id = 'imagenes';
        document.getElementById('productoForm').appendChild(imagenesInput);
    }

    // Reiniciar arrays
    uploadedImageNames = [];
    existingImages = [];

    // Verificar si el producto tiene imágenes
    if (producto.imagenes && producto.imagenes.length > 0) {
        console.log("Imágenes encontradas:", producto.imagenes);
        
        // Guardar referencia de las imágenes existentes
        existingImages = producto.imagenes;
        uploadedImageNames = producto.imagenes.map(img => img.imagen);
        document.getElementById('imagenes').value = uploadedImageNames.join(',');

        // Definir la variable global para la imagen principal
        window.producto_imagen_principal = producto.imagen_principal || null;
        
        console.log("Imagen principal:", window.producto_imagen_principal);

        // Mostrar el carrusel
        document.getElementById('imagenesCarousel').style.display = 'block';
        
        // Forzar la inicialización del carrusel 
        setTimeout(() => {
            actualizarCarruselDirecto();
        }, 500);
    } else {
        console.warn("No se encontraron imágenes para el producto");
        document.getElementById('imagenesCarousel').style.display = 'none';
        document.getElementById('imagenes').value = '';
    }
}

/**
 * Actualiza el carrusel directamente sin depender del Dropzone
 */
function actualizarCarruselDirecto() {
    const inner = document.getElementById("carouselInner");
    const carousel = document.getElementById("imagenesCarousel");
    
    // Verificar elementos DOM
    if (!inner || !carousel) {
        console.error('No se encontraron los elementos del carrusel en el DOM');
        return;
    }

    // Verificar si tenemos imágenes
    if (!existingImages || existingImages.length === 0) {
        console.warn('No hay imágenes para mostrar');
        carousel.style.display = 'none';
        return;
    }

    // Mostrar carrusel si hay imágenes
    carousel.style.display = 'block';

    // Limpiar contenedor
    inner.innerHTML = "";

    // Crear elementos para cada imagen
    existingImages.forEach((img, index) => {
        const isActive = index === 0;
        const isPrincipal = img.principal == 1 || img.imagen === window.producto_imagen_principal;
        
        // URL absoluta para la imagen
        const imgSrc = `${window.location.origin}/cye/sistema/img/productos/${img.imagen}`;
        
        // Crear elemento del carrusel
        const item = document.createElement("div");
        item.classList.add("carousel-item");
        if (isActive) item.classList.add("active");
        if (isPrincipal) item.classList.add("dz-principal");

        const wrapper = document.createElement("div");
        wrapper.className = "position-relative";

        // Imagen
        const imgEl = document.createElement("img");
        imgEl.src = imgSrc;
        imgEl.className = "d-block w-100";
        imgEl.style.maxHeight = "300px"; // Limitar altura para mejor visualización
        imgEl.style.objectFit = "contain"; // Mantener proporción de la imagen
        imgEl.alt = img.imagen;
        imgEl.onerror = function() {
            console.error(`No se pudo cargar la imagen: ${imgSrc}`);
            this.src = "img/placeholder.png"; // Imagen de reemplazo
            this.style.border = "1px solid red";
            
            // Intentar con rutas alternativas
            mostrarImagenDiagnostico(img.imagen);
        };

        wrapper.appendChild(imgEl);

        // Botones de acción
        const actionButtons = document.createElement("div");
        actionButtons.className = "carousel-div-btns position-absolute top-0 end-0 p-2";

        // Botón principal
        const principalBtn = document.createElement("button");
        principalBtn.className = `btn btn-sm ${isPrincipal ? 'btn-success' : 'btn-primary'} principal-button`;
        principalBtn.textContent = isPrincipal ? "Principal ✓" : "Principal";
        principalBtn.addEventListener("click", function(e) {
            e.preventDefault();
            e.stopPropagation();

            // Quitar marca de principal de todas las imágenes
            existingImages.forEach(image => {
                image.principal = 0;
            });
            
            // Marcar esta como principal
            img.principal = 1;
            window.producto_imagen_principal = img.imagen;
            
            // Actualizar en la base de datos
            marcarImagenPrincipal(img.imagen);
            
            // Actualizar carrusel
            actualizarCarruselDirecto();
        });

        // Botón eliminar
        const removeBtn = document.createElement("button");
        removeBtn.className = "btn btn-sm btn-danger me-2";
        removeBtn.textContent = "Eliminar";
        removeBtn.addEventListener("click", function(e) {
            e.preventDefault();
            e.stopPropagation();
            
            // Eliminar la imagen del array
            const index = existingImages.findIndex(image => image.imagen === img.imagen);
            if (index > -1) {
                existingImages.splice(index, 1);
            }
            
            // Eliminar del array de nombres
            const nameIndex = uploadedImageNames.indexOf(img.imagen);
            if (nameIndex > -1) {
                uploadedImageNames.splice(nameIndex, 1);
                document.getElementById('imagenes').value = uploadedImageNames.join(',');
            }
            
            // Eliminar del servidor
            $.ajax({
                url: 'php/deleteImagenProducto.php',
                type: 'POST',
                data: {
                    filename: img.imagen,
                    id_producto: productId
                },
                success: function (response) {
                    try {
                        const result = JSON.parse(response);
                        if (result.status === 'success') {
                            console.log('Imagen eliminada correctamente:', img.imagen);
                        } else {
                            console.error('Error al eliminar imagen:', result.message);
                        }
                    } catch (e) {
                        console.error('Error al procesar respuesta:', e);
                    }
                },
                error: function (xhr, status, error) {
                    console.error('Error AJAX al eliminar imagen:', error);
                }
            });
            
            // Actualizar carrusel
            actualizarCarruselDirecto();
        });

        actionButtons.appendChild(removeBtn);
        actionButtons.appendChild(principalBtn);
        
        wrapper.appendChild(actionButtons);
        item.appendChild(wrapper);
        inner.appendChild(item);
    });

    // Inicializar carrusel Bootstrap
    try {
        new bootstrap.Carousel(document.getElementById('imagenesCarousel'));
        console.log('Carrusel inicializado correctamente');
        
        // Mostrar información de diagnóstico
        console.log('Imágenes en carrusel:', inner.querySelectorAll('.carousel-item').length);
        console.log('Primera imagen:', inner.querySelector('.carousel-item img')?.src || 'No hay imagen');
    } catch (error) {
        console.error('Error al inicializar Bootstrap Carousel:', error);
    }
    
    
    // Solo añadir si no existe ya
    if (!document.querySelector('.text-center.mt-2.mb-2 button')) {
        carousel.parentNode.insertBefore(btnContainer, carousel.nextSibling);
    }
}

/**
 * Muestra imagen de diagnóstico para verificar rutas
 */
function mostrarImagenDiagnostico(imagen) {
    const rutaBase = `${window.location.origin}/cye/sistema/img/productos/`;
    const rutaImagen = rutaBase + imagen;
    
    const testImagen = new Image();
    testImagen.onload = function() {
        console.log("✅ Imagen cargada correctamente:", rutaImagen);
    };
    testImagen.onerror = function() {
        console.error("❌ Error al cargar la imagen:", rutaImagen);
        console.log("Intentando rutas alternativas...");
        
        const alternativas = [
            `${window.location.origin}/sistema/img/productos/${imagen}`,
            `/cye/sistema/img/productos/${imagen}`,
            `/sistema/img/productos/${imagen}`,
            `img/productos/${imagen}`
        ];
        
        alternativas.forEach(ruta => {
            const test = new Image();
            test.onload = function() {
                console.log("✅ Alternativa correcta:", ruta);
            };
            test.onerror = function() {
                console.log("❌ Alternativa incorrecta:", ruta);
            };
            test.src = ruta;
        });
    };
    testImagen.src = rutaImagen;
}

/**
 * @param {string} productId 
 */
function agregarCampoIdProducto(productId) {
    const hiddenInput = document.createElement('input');
    hiddenInput.type = 'hidden';
    hiddenInput.name = 'id_producto';
    hiddenInput.id = 'id_producto';
    hiddenInput.value = productId;
    document.getElementById('productoForm').appendChild(hiddenInput);
}

/**
 * Inicializa los Dropzones para carga de imágenes y archivos
 */
function initDropzones() {
    // Verificar que los elementos existen antes de inicializar
    const elementosNecesarios = ['imagenesForm', 'carouselInner', 'imagenesCarousel', 'pdfForm', 'autocadForm'];
    let todosPresentar = true;
    
    elementosNecesarios.forEach(id => {
        if (!document.getElementById(id)) {
            console.error(`Elemento ${id} no encontrado en el DOM`);
            todosPresentar = false;
        }
    });
    
    if (!todosPresentar) {
        console.error('No se pueden inicializar los Dropzones porque faltan elementos DOM');
        return;
    }
    
    inicializarDropzoneImagenes();
    inicializarDropzonePDF();
    inicializarDropzoneAutocad();
}

/**
 * Inicializa el Dropzone para imágenes del producto
 */
function inicializarDropzoneImagenes() {
    const imagenesDropzone = new Dropzone("#imagenesForm", {
        url: "php/uploadImagenProducto.php",
        paramName: "file",
        uploadMultiple: false,
        maxFilesize: 2,
        maxFiles: 10,
        acceptedFiles: "image/*",
        addRemoveLinks: false,
        dictDefaultMessage: "",
        dictRemoveFile: "Eliminar",
        dictFileTooBig: "El archivo es demasiado grande ({{filesize}}MB). Tamaño máximo: {{maxFilesize}}MB.",
        dictInvalidFileType: "Tipo de archivo no válido. Solo se permiten imágenes.",
        autoProcessQueue: true,
        previewsContainer: false, // No usamos el contenedor por defecto
        clickable: true,

        init: function () {
            const myDropzone = this;

            this.on("addedfile", function (file) {
                // Validación de tamaño y tipo de archivo
                if (!file.size && file.accepted) {
                    // Es un archivo mock de una imagen existente, no validar
                    return true;
                }

                if (file.size > this.options.maxFilesize * 1024 * 1024) {
                    const mensaje = `El archivo "${file.name}" es demasiado grande (${(file.size / (1024 * 1024)).toFixed(2)}MB). Tamaño máximo: ${this.options.maxFilesize}MB.`;
                    mostrarError("Archivo demasiado grande", mensaje);
                    this.removeFile(file);
                    return false;
                }

                if (!file.type.match(/image\/.*/)) {
                    mostrarError("Formato inválido", "Solo se permiten archivos de imagen.");
                    this.removeFile(file);
                    return false;
                }

                // Crear URL temporal para la previsualización
                file.tempURL = URL.createObjectURL(file);
                file.tempName = file.name;

                // Actualizar carrusel con archivos temporales
                actualizarCarrusel();
            });

            this.on("success", function (file, response) {
                try {
                    const data = JSON.parse(response);
                    if (data.status === 'success') {
                        // Agregar a la lista de imágenes subidas
                        uploadedImageNames.push(data.filename);
                        document.getElementById('imagenes').value = uploadedImageNames.join(',');

                        // Asignar el nombre real del archivo al objeto file
                        file.serverName = data.filename;

                        // Añadir a existingImages para mantener consistencia
                        existingImages.push({
                            id: Date.now(), // ID temporal
                            imagen: data.filename,
                            principal: existingImages.length === 0 ? 1 : 0
                        });

                        // Si aún no hay imagen principal, marcar esta como principal
                        if (uploadedImageNames.length === 1) {
                            marcarImagenPrincipal(data.filename);
                        }

                        // Actualizar carrusel para mostrar la imagen recién subida
                        actualizarCarruselDirecto();
                    } else {
                        console.error("Error al subir imagen:", data.message);
                        this.removeFile(file);
                        mostrarError("Error", data.message);
                    }
                } catch (e) {
                    console.error("Error al procesar respuesta:", e);
                    this.removeFile(file);
                    mostrarError("Error", "Error al procesar la respuesta del servidor");
                }
            });

            this.on("removedfile", function (file) {
                // Si el archivo tenía un nombre asignado por el servidor
                if (file.serverName) {
                    const filename = file.serverName;

                    // Eliminar del array local
                    const imageIndex = uploadedImageNames.indexOf(filename);
                    if (imageIndex > -1) {
                        uploadedImageNames.splice(imageIndex, 1);
                        document.getElementById('imagenes').value = uploadedImageNames.join(',');
                    }

                    // Eliminar de existingImages
                    const existingIndex = existingImages.findIndex(img => img.imagen === filename);
                    if (existingIndex > -1) {
                        existingImages.splice(existingIndex, 1);
                    }

                    // Eliminar del servidor
                    $.ajax({
                        url: 'php/deleteImagenProducto.php',
                        type: 'POST',
                        data: {
                            filename: filename,
                            id_producto: productId
                        },
                        success: function (response) {
                            try {
                                const result = JSON.parse(response);
                                if (result.status === 'success') {
                                    console.log('Imagen eliminada correctamente:', filename);
                                } else {
                                    console.error('Error al eliminar imagen:', result.message);
                                }
                            } catch (e) {
                                console.error('Error al procesar respuesta:', e);
                            }
                        },
                        error: function (xhr, status, error) {
                            console.error('Error AJAX al eliminar imagen:', error);
                        }
                    });
                }

                // Actualizar carrusel después de eliminar
                actualizarCarruselDirecto();
            });

            // Cuando cargamos el producto, inicializamos el carrusel
            if (existingImages && existingImages.length > 0) {
                console.log("Inicializando dropzone con imágenes existentes:", existingImages);

                existingImages.forEach(img => {
                    const mockFile = {
                        name: img.imagen,
                        serverName: img.imagen,
                        size: 12345,
                        accepted: true,
                        isPrincipal: img.principal == 1 || img.imagen === window.producto_imagen_principal
                    };

                    console.log("Añadiendo imagen:", mockFile);

                    myDropzone.files.push(mockFile);
                    myDropzone.emit("addedfile", mockFile);
                    myDropzone.emit("complete", mockFile);
                });

                // Inicializar carrusel con las imágenes existentes
                setTimeout(() => {
                    actualizarCarruselDirecto();
                }, 100);
            }
        }
    });

    return imagenesDropzone;
}

/**
 * Actualiza el carrusel con las imágenes cargadas
 * (Se mantiene para compatibilidad pero se usa actualizarCarruselDirecto)
 */
function actualizarCarrusel() {
    // Redirigir a la nueva función
    actualizarCarruselDirecto();
}

/**
 * Marca una imagen como principal
 * @param {string} filename - Nombre del archivo a marcar como principal
 */
function marcarImagenPrincipal(filename) {
    console.log("Marcando como principal:", filename);
    // Si estamos editando un producto existente
    if (productId) {
        $.ajax({
            url: 'database/model/productos.php',
            type: 'POST',
            data: {
                action: "setImagenPrincipal",
                id_producto: productId,
                imagen_principal: filename
            },
            success: function (response) {
                try {
                    const result = JSON.parse(response);
                    if (result.status === 'success') {
                        console.log('Imagen principal establecida correctamente');
                    } else {
                        console.error('Error al establecer imagen principal:', result.message);
                    }
                } catch (e) {
                    console.error('Error al procesar respuesta:', e);
                }
            },
            error: function (xhr, status, error) {
                console.error('Error AJAX al establecer imagen principal:', error);
            }
        });
    }
}

/**
 * Inicializa el Dropzone para archivos PDF
 */
function inicializarDropzonePDF() {
    const pdfDropzone = new Dropzone("#pdfForm", {
        url: "php/uploadPdf.php",
        paramName: "plano",
        maxFilesize: 5, // MB
        maxFiles: 1,
        acceptedFiles: "application/pdf",
        addRemoveLinks: true,
        dictDefaultMessage: "",
        dictRemoveFile: "Eliminar",
        dictFileTooBig: "El archivo es demasiado grande ({{filesize}}MB). Tamaño máximo: {{maxFilesize}}MB.",
        dictInvalidFileType: "Tipo de archivo no válido. Solo se permiten archivos PDF.",
        previewTemplate: "<div style='display:none'></div>", // Ocultamos la previsualización predeterminada
        clickable: true,

        init: function () {
            const myDropzone = this;

            this.on("addedfile", function (file) {
                // Validación de tamaño y tipo para archivos reales (no mock)
                if (validarArchivo(file, this) === false) return;

                // Mostrar previsualización personalizada para PDFs
                mostrarPrevisualizacionPDF(file, myDropzone);
            });

            this.on("success", function (file, response) {
                try {
                    const data = JSON.parse(response);
                    if (data.status === 'success') {
                        pdfFileName = data.filename;
                        document.getElementById('pdf').value = pdfFileName;

                        mostrarNotificacionExito('PDF subido correctamente');
                    } else {
                        console.error("Error al subir PDF:", data.message);
                        this.removeFile(file);
                        mostrarError("Error", data.message);
                    }
                } catch (e) {
                    console.error("Error al procesar respuesta:", e);
                    this.removeFile(file);
                    mostrarError("Error", "Error al procesar la respuesta del servidor");
                }
            });

            this.on("removedfile", function (file) {
                // No eliminar inmediatamente del DOM
                const previewElement = file.previewElement;

                // Si hay un PDF subido, eliminarlo del servidor
                if (pdfFileName) {
                    $.ajax({
                        url: 'php/deleteFile.php',
                        type: 'POST',
                        data: {
                            filename: pdfFileName,
                            type: 'pdf',
                            id_producto: productId // Añadir ID del producto para actualizar la BD
                        },
                        success: function (response) {
                            try {
                                const result = JSON.parse(response);
                                if (result.status === 'success') {
                                    // Solo eliminar del DOM tras confirmar eliminación
                                    if (previewElement && previewElement.parentNode) {
                                        previewElement.parentNode.removeChild(previewElement);
                                    }
                                    pdfFileName = null;
                                    document.getElementById('pdf').value = "";
                                } else {
                                    mostrarError("Error", result.message || 'Error al eliminar el PDF');
                                }
                            } catch (e) {
                                console.error("Error al procesar la respuesta:", e);
                            }
                        },
                        error: function () {
                            mostrarError("Error", "Error de conexión al eliminar el PDF");
                        }
                    });
                }
            });

            this.on("maxfilesexceeded", function (file) {
                this.removeAllFiles();
                this.addFile(file);
            });
        }
    });

    return pdfDropzone;
}

/**
 * Inicializa el Dropzone para archivos AutoCAD
 */
function inicializarDropzoneAutocad() {
    const autocadDropzone = new Dropzone("#autocadForm", {
        url: "php/uploadAutocad.php",
        paramName: "file",
        maxFilesize: 10, // MB
        maxFiles: 1,
        acceptedFiles: ".dwg,.dxf,.dwf",
        addRemoveLinks: true,
        dictDefaultMessage: "",
        dictRemoveFile: "Eliminar",
        dictFileTooBig: "El archivo es demasiado grande ({{filesize}}MB). Tamaño máximo: {{maxFilesize}}MB.",
        dictInvalidFileType: "Tipo de archivo no válido. Solo se permiten archivos .dwg, .dxf o .dwf",
        previewTemplate: "<div style='display:none'></div>", // Ocultamos la previsualización predeterminada
        clickable: true,

        init: function () {
            const myDropzone = this;

            this.on("addedfile", function (file) {
                // Validación de tamaño y tipo para archivos reales (no mock)
                if (validarArchivo(file, this) === false) return;

                // Mostrar previsualización personalizada
                mostrarPrevisualizacionAutocad(file, myDropzone);
            });

            this.on("success", function (file, response) {
                try {
                    const data = JSON.parse(response);
                    if (data.status === 'success') {
                        autocadFileName = data.filename;
                        document.getElementById('autocard').value = autocadFileName;
                        mostrarNotificacionExito('Archivo AutoCAD subido correctamente');
                    } else {
                        console.error("Error al subir AutoCAD:", data.message);
                        this.removeFile(file);
                        mostrarError("Error", data.message);
                    }
                } catch (e) {
                    console.error("Error al procesar respuesta:", e);
                    this.removeFile(file);
                    mostrarError("Error", "Error al procesar la respuesta del servidor");
                }
            });

            this.on("removedfile", function (file) {
                // No eliminar inmediatamente del DOM
                const previewElement = file.previewElement;

                // Si hay un archivo AutoCAD subido, eliminarlo del servidor
                if (autocadFileName) {
                    $.ajax({
                        url: 'php/deleteFile.php',
                        type: 'POST',
                        data: {
                            filename: autocadFileName,
                            type: 'autocad',
                            id_producto: productId // Añadir ID del producto para actualizar la BD
                        },
                        success: function (response) {
                            try {
                                const result = JSON.parse(response);
                                if (result.status === 'success') {
                                    // Solo eliminar del DOM tras confirmar eliminación
                                    if (previewElement && previewElement.parentNode) {
                                        previewElement.parentNode.removeChild(previewElement);
                                    }
                                    autocadFileName = null;
                                    document.getElementById('autocard').value = '';
                                } else {
                                    mostrarError("Error", result.message || 'Error al eliminar el archivo AutoCAD');
                                }
                            } catch (e) {
                                console.error("Error al procesar la respuesta:", e);
                            }
                        },
                        error: function () {
                            mostrarError("Error", "Error de conexión al eliminar el archivo AutoCAD");
                        }
                    });
                }
            });

            this.on("maxfilesexceeded", function (file) {
                this.removeAllFiles();
                this.addFile(file);
            });
        }
    });

    return autocadDropzone;
}

/**
 * Valida un archivo antes de procesarlo (tamaño y tipo)
 * @param {Object} file - Objeto del archivo
 * @param {Object} dropzone - Instancia de Dropzone
 * @param {string} [tipo=''] - Tipo específico de validación adicional
 * @returns {boolean} - true si el archivo es válido, false en caso contrario
 */
function validarArchivo(file, dropzone, tipo = '') {
    // No validar archivos mock
    if (!file.size && file.accepted) {
        return true;
    }

    // Validar tamaño
    if (file.size > dropzone.options.maxFilesize * 1024 * 1024) {
        const mensaje = `El archivo "${file.name}" es demasiado grande (${(file.size / (1024 * 1024)).toFixed(2)}MB). Tamaño máximo: ${dropzone.options.maxFilesize}MB.`;
        mostrarError("Archivo demasiado grande", mensaje);
        dropzone.removeFile(file);
        return false;
    }

    // Validar tipo para imágenes
    if (tipo === 'image' && !file.type.match(/image\/.*/)) {
        mostrarError("Formato inválido", "Solo se permiten archivos de imagen.");
        dropzone.removeFile(file);
        return false;
    }

    return true;
}

/**
 * Muestra la previsualización de un archivo PDF
 * @param {Object} file - Objeto del archivo
 * @param {Object} dropzone - Instancia de Dropzone
 */
function mostrarPrevisualizacionPDF(file, dropzone) {
    // Crear previsualización personalizada
    const pdfPreview = document.createElement('div');
    pdfPreview.className = 'pdf-preview mt-3 p-3 border rounded';

    const fileInfo = document.createElement('div');
    fileInfo.className = 'd-flex align-items-center';

    const icon = document.createElement('i');
    icon.className = 'fas fa-file-pdf text-danger me-2 fa-2x';

    const fileName = document.createElement('span');
    fileName.textContent = file.name;
    fileName.className = 'flex-grow-1';

    const removeBtn = document.createElement('button');
    removeBtn.className = 'btn btn-sm btn-danger ms-2';
    removeBtn.textContent = 'Eliminar';
    removeBtn.addEventListener('click', function (e) {
        e.preventDefault();
        e.stopPropagation();
        dropzone.removeFile(file);
    });

    // Ensamblar elementos
    fileInfo.appendChild(icon);
    fileInfo.appendChild(fileName);
    fileInfo.appendChild(removeBtn);
    pdfPreview.appendChild(fileInfo);

    // Agregar al DOM
    document.querySelector('#pdfForm').nextElementSibling.appendChild(pdfPreview);

    // Guardar referencia al elemento para poder eliminarlo más tarde
    file.previewElement = pdfPreview;
}

/**
 * Muestra la previsualización de un archivo AutoCAD
 * @param {Object} file - Objeto del archivo
 * @param {Object} dropzone - Instancia de Dropzone
 */
function mostrarPrevisualizacionAutocad(file, dropzone) {
    // Crear previsualización personalizada
    const autocadPreview = document.createElement('div');
    autocadPreview.className = 'autocad-preview mt-3 p-3 border rounded';

    const fileInfo = document.createElement('div');
    fileInfo.className = 'd-flex align-items-center';

    const icon = document.createElement('i');
    icon.className = 'fas fa-file-alt text-primary me-2 fa-2x';

    const fileName = document.createElement('span');
    fileName.textContent = file.name;
    fileName.className = 'flex-grow-1';

    const removeBtn = document.createElement('button');
    removeBtn.className = 'btn btn-sm btn-danger ms-2';
    removeBtn.textContent = 'Eliminar';
    removeBtn.addEventListener('click', function (e) {
        e.preventDefault();
        e.stopPropagation();
        dropzone.removeFile(file);
    });

    // Ensamblar elementos
    fileInfo.appendChild(icon);
    fileInfo.appendChild(fileName);
    fileInfo.appendChild(removeBtn);
    autocadPreview.appendChild(fileInfo);

    // Agregar al DOM
    document.querySelector('#autocadForm').nextElementSibling.appendChild(autocadPreview);

    // Guardar referencia al elemento para poder eliminarlo más tarde
    file.previewElement = autocadPreview;
}

/**
 * Carga las subcategorías desde el servidor
 */
function loadSubcategorias() {
    $.ajax({
        url: 'database/model/productos.php',
        type: 'POST',
        data: { "action": "getActiveSubcategorias" },
        success: function (response) {
            try {
                let subcategorias = JSON.parse(response);
                let select = document.getElementById('id_subcategoria');

                if (select) {
                    select.innerHTML = '<option value="">Selecciona una subcategoría</option>';

                    // Agrupar por categoría
                    const categorias = {};
                    subcategorias.forEach(item => {
                        if (!categorias[item.id_categoria]) {
                            categorias[item.id_categoria] = {
                                nombre: `${item.categoria_es} / ${item.categoria_en}`,
                                subcategorias: []
                            };
                        }
                        categorias[item.id_categoria].subcategorias.push(item);
                    });

                    // Crear optgroups por categoría
                    for (const catId in categorias) {
                        const optgroup = document.createElement('optgroup');
                        optgroup.label = categorias[catId].nombre;

                        categorias[catId].subcategorias.forEach(subcat => {
                            const option = document.createElement('option');
                            option.value = subcat.id_subcategoria;
                            option.textContent = `${subcat.nombre_es} / ${subcat.nombre_en}`;
                            optgroup.appendChild(option);
                        });

                        select.appendChild(optgroup);
                    }
                }
            } catch (e) {
                console.error("Error al procesar la respuesta:", e);
                mostrarError("Error", "Error al cargar las subcategorías");
            }
        },
        error: function (xhr, status, error) {
            console.error("Error AJAX:", error);
            mostrarError("Error", "Error de conexión al servidor");
        }
    });
}

/**
 * Configura la funcionalidad de traducción automática
 */
function setupTranslation() {
    // Sistema de traducción automática español -> inglés
    let typingTimer;
    const doneTypingInterval = 800; // tiempo en ms

    // Evento para el nombre en español
    const nombreEs = document.getElementById('nombre_es');
    if (nombreEs) {
        nombreEs.addEventListener('input', function () {
            clearTimeout(typingTimer);
            const texto = this.value.trim();

            if (texto === '') {
                document.getElementById('nombre_en').value = '';
                return;
            }

            typingTimer = setTimeout(function () {
                if (texto.length > 0) {
                    // Primero probamos con diccionario local
                    let traduccionLocal = localTranslate(texto);
                    if (traduccionLocal) {
                        document.getElementById('nombre_en').value = traduccionLocal;
                    } else {
                        // Si no hay coincidencia local, usamos API gratuita
                        translateText(texto, 'nombre_en');
                    }
                }
            }, doneTypingInterval);
        });
    }

    // Evento para descripción en español
    if ($('#descripcion_es').length) {
        // Usar evento change en lugar de input para Summernote
        $('#descripcion_es').on('summernote.change', function () {
            clearTimeout(typingTimer);
            const textoHtml = $(this).summernote('code').trim();

            if (textoHtml === '' || textoHtml === '<p><br></p>') {
                $('#descripcion_en').summernote('code', '');
                return;
            }

            typingTimer = setTimeout(function () {
                if (textoHtml.length > 0) {
                    // Extraer texto sin etiquetas HTML de manera más robusta
                    const textoPlano = extraerTextoPlano(textoHtml);

                    if (textoPlano.trim().length > 0) {
                        // Usar traducción local primero si es un texto corto
                        if (textoPlano.length < 100) {
                            const traduccionLocal = localTranslate(textoPlano);
                            if (traduccionLocal) {
                                $('#descripcion_en').summernote('code', '<p>' + traduccionLocal + '</p>');
                                return;
                            }
                        }

                        // Si no hay traducción local o es un texto largo, usar API
                        translateText(textoPlano, 'descripcion_en', true);
                    }
                }
            }, doneTypingInterval);
        });

        // Añadir también escucha para cambios manuales (keyup)
        $('#descripcion_es').on('summernote.keyup', function () {
            clearTimeout(typingTimer);
            const textoHtml = $(this).summernote('code').trim();

            if (textoHtml === '' || textoHtml === '<p><br></p>') {
                $('#descripcion_en').summernote('code', '');
                return;
            }

            typingTimer = setTimeout(function () {
                const textoPlano = extraerTextoPlano(textoHtml);
                if (textoPlano.trim().length > 0) {
                    translateText(textoPlano, 'descripcion_en', true);
                }
            }, doneTypingInterval * 2); // Tiempo más largo para evitar llamadas excesivas
        });
    }
}

/**
 * Extrae texto plano de un fragmento HTML
 * @param {string} html - Código HTML
 * @returns {string} - Texto plano extraído
 */
function extraerTextoPlano(html) {
    const tempDiv = document.createElement('div');
    tempDiv.innerHTML = html;
    return tempDiv.textContent || tempDiv.innerText || '';
}

/**
 * Traduce términos comunes usando un diccionario local
 * @param {string} text - Texto a traducir
 * @returns {string|null} - Traducción o null si no se encuentra
 */
function localTranslate(text) {
    // Diccionario de términos comunes (ampliable)
    const commonTranslations = {
        "instalación eléctrica": "electrical installation",
        "poste de luz": "light pole",
        "tablero eléctrico": "electrical panel",
        "cable": "cable",
        "transformador": "transformer",
        "energía solar": "solar energy",
        "iluminación": "lighting",
        "panel solar": "solar panel",
        "interruptor": "switch",
        "tomacorriente": "power outlet",
        "conductor eléctrico": "electrical conductor",
        "clavija": "plug",
        "enchufe": "socket",
        "fusible": "fuse",
        "aislante": "insulator",
        "subestación": "substation",
        "generador": "generator",
        "batería": "battery",
        "inversor": "inverter",
        "electricista": "electrician",
        "herramientas": "tools",
        "instalador": "installer",
        "ducto": "duct",
        "canaleta": "cable tray",
        "conexión": "connection",
        "sistema eléctrico": "electrical system"
    };

    // Convertir a minúsculas para buscar en el diccionario
    const textLower = text.toLowerCase();

    // Comprobar si existe una traducción exacta
    if (commonTranslations[textLower]) {
        // Mantener la capitalización original
        if (text[0] === text[0].toUpperCase()) {
            return commonTranslations[textLower].charAt(0).toUpperCase() +
                commonTranslations[textLower].slice(1);
        }
        return commonTranslations[textLower];
    }

    // Devolver null si no hay coincidencia en el diccionario
    return null;
}

/**
 * Traduce un texto utilizando una API externa
 * @param {string} text - Texto a traducir
 * @param {string} targetId - ID del elemento donde colocar la traducción
 * @param {boolean} isHtml - Indica si el destino es un editor HTML
 */
function translateText(text, targetId, isHtml = false) {
    const targetElement = document.getElementById(targetId);
    if (!targetElement) return;

    // Mostrar indicador de carga
    if (isHtml) {
        $('#' + targetId).next('.note-editor').addClass('loading-translation');
    } else {
        targetElement.classList.add('loading-translation');
    }

    // Usar la API de MyMemory (gratuita con límites)
    $.ajax({
        url: `https://api.mymemory.translated.net/get?q=${encodeURIComponent(text)}&langpair=es|en`,
        type: 'GET',
        success: function (data) {
            if (data && data.responseData && data.responseData.translatedText) {
                if (isHtml) {
                    // Preservar formato HTML básico
                    let traduccion = data.responseData.translatedText;

                    // Asegurar que la traducción tenga etiquetas de párrafo
                    if (!traduccion.startsWith('<')) {
                        traduccion = '<p>' + traduccion + '</p>';
                    }

                    $('#' + targetId).summernote('code', traduccion);
                } else {
                    targetElement.value = data.responseData.translatedText;
                }
            } else {
                console.warn("API primaria falló, usando respaldo:", data);
                fallbackTranslation(text, targetId, isHtml);
            }

            if (isHtml) {
                $('#' + targetId).next('.note-editor').removeClass('loading-translation');
            } else {
                targetElement.classList.remove('loading-translation');
            }
        },
        error: function (xhr, status, error) {
            console.error(`Error en API primaria (${targetId}):`, error);
            fallbackTranslation(text, targetId, isHtml);

            if (isHtml) {
                $('#' + targetId).next('.note-editor').removeClass('loading-translation');
            } else {
                targetElement.classList.remove('loading-translation');
            }
        }
    });
}

/**
 * Función de respaldo para traducción si la API principal falla
 * @param {string} text - Texto a traducir
 * @param {string} targetId - ID del elemento donde colocar la traducción
 * @param {boolean} isHtml - Indica si el destino es un editor HTML
 */
function fallbackTranslation(text, targetId, isHtml = false) {
    // Usar LibreTranslate como alternativa
    $.ajax({
        url: 'https://libretranslate.de/translate',
        type: 'POST',
        data: JSON.stringify({
            q: text,
            source: 'es',
            target: 'en'
        }),
        contentType: 'application/json',
        success: function (response) {
            if (response && response.translatedText) {
                if (isHtml) {
                    $('#' + targetId).summernote('code', '<p>' + response.translatedText + '</p>');
                } else {
                    document.getElementById(targetId).value = response.translatedText;
                }
            } else {
                simpleFallbackTranslation(text, targetId, isHtml);
            }
        },
        error: function () {
            simpleFallbackTranslation(text, targetId, isHtml);
        }
    });
}

/**
 * Traducción básica para casos donde todas las APIs fallen
 * @param {string} text - Texto a traducir
 * @param {string} targetId - ID del elemento donde colocar la traducción
 * @param {boolean} isHtml - Indica si el destino es un editor HTML
 */
function simpleFallbackTranslation(text, targetId, isHtml = false) {
    // Si todas las APIs fallan, aplicar transformaciones básicas
    let translation = text
        .replace(/ción/g, 'tion')
        .replace(/dad/g, 'ty')
        .replace(/dor/g, 'tor')
        .replace(/ar$/g, 'ate')
        .replace(/co$/g, 'cal')
        .replace(/ía/g, 'ia')
        .replace(/ico$/g, 'ical')
        .replace(/ista/g, 'ist')
        .replace(/ismo/g, 'ism')
        .replace(/eo$/g, 'ea')
        .replace(/ble$/g, 'ble');

    // Capitalizar primera letra si el original también lo estaba
    if (text[0] === text[0].toUpperCase()) {
        translation = translation.charAt(0).toUpperCase() + translation.slice(1);
    }

    if (isHtml) {
        $('#' + targetId).summernote('code', '<p>' + translation + '</p>');
    } else {
        document.getElementById(targetId).value = translation;
    }

    // Informar al usuario que es una traducción aproximada
    mostrarNotificacion('info', 'Traducción aproximada', 'Por favor, verifica y ajusta la traducción si es necesario');
}

/**
 * Actualiza el producto con los datos del formulario
 */
function updateProducto() {
    // Validación básica
    const nombre_es = document.getElementById('nombre_es').value.trim();
    const nombre_en = document.getElementById('nombre_en').value.trim();
    const id_subcategoria = document.getElementById('id_subcategoria').value;
    const sku = document.getElementById('sku').value.trim();
    const id_producto = document.getElementById('id_producto').value;

    if (!id_producto || !nombre_es || !nombre_en || !id_subcategoria || !sku) {
        mostrarError('Error de validación', 'Por favor completa todos los campos obligatorios');
        return;
    }

    // Validar el contenido de los editores
    const descripcion_es = $('#descripcion_es').summernote('isEmpty') ? '' : $('#descripcion_es').summernote('code');
    const descripcion_en = $('#descripcion_en').summernote('isEmpty') ? '' : $('#descripcion_en').summernote('code');

    // Mostrar indicador de carga
    Swal.fire({
        title: 'Actualizando producto...',
        text: 'Por favor espera',
        allowOutsideClick: false,
        didOpen: () => {
            Swal.showLoading();
        }
    });

    // Recopilar datos del formulario
    const formData = new FormData(document.getElementById('productoForm'));
    formData.append('action', 'updateProducto');
    formData.append('descripcion_es', descripcion_es);
    formData.append('descripcion_en', descripcion_en);
    formData.append('id_producto', id_producto);

    // Obtener la imagen principal
    let imagenPrincipal = null;
    if (existingImages && existingImages.length > 0) {
        const imgPrincipal = existingImages.find(img => img.principal == 1);
        if (imgPrincipal) {
            imagenPrincipal = imgPrincipal.imagen;
        } else if (window.producto_imagen_principal) {
            imagenPrincipal = window.producto_imagen_principal;
        } else {
            imagenPrincipal = existingImages[0].imagen;
        }
    }

    // Agregar imagen principal al formulario
    if (imagenPrincipal) {
        formData.append('imagen_principal', imagenPrincipal);
        console.log('Imagen principal seleccionada:', imagenPrincipal);
    }

    // Enviar solicitud AJAX
    $.ajax({
        url: 'database/model/productos.php',
        type: 'POST',
        data: formData,
        processData: false,
        contentType: false,
        success: function (response) {
            try {
                const result = JSON.parse(response);

                if (result.status === 'success') {
                    Swal.fire({
                        icon: 'success',
                        title: 'Producto actualizado',
                        text: result.message,
                        showConfirmButton: false,
                        timer: 1500
                    }).then(() => {
                        window.location.href = 'productos.php';
                    });
                } else {
                    mostrarError('Error', result.message || 'Error al actualizar el producto');
                }
            } catch (e) {
                console.error("Error al procesar la respuesta:", e);
                mostrarError('Error', 'Error al procesar la respuesta del servidor');
            }
        },
        error: function (xhr, status, error) {
            console.error("Error AJAX:", error);
            mostrarError('Error', 'Error de conexión al servidor');
        }
    });
}

/**
 * Muestra un mensaje de error usando SweetAlert
 * @param {string} titulo - Título del mensaje
 * @param {string} texto - Texto del mensaje
 */
function mostrarError(titulo, texto) {
    console.error(`${titulo}: ${texto}`);
    
    Swal.fire({
        icon: 'error',
        title: titulo,
        text: texto
    });
}

/**
 * Muestra una notificación de éxito
 * @param {string} mensaje - Mensaje a mostrar
 */
function mostrarNotificacionExito(mensaje) {
    Swal.fire({
        position: 'top-end',
        icon: 'success',
        title: mensaje,
        showConfirmButton: false,
        timer: 1500
    });
}

/**
 * Muestra una notificación genérica
 * @param {string} tipo - Tipo de notificación (success, error, warning, info)
 * @param {string} titulo - Título de la notificación
 * @param {string} mensaje - Mensaje a mostrar
 */
function mostrarNotificacion(tipo, titulo, mensaje) {
    Swal.fire({
        icon: tipo,
        title: titulo,
        text: mensaje,
        toast: true,
        position: 'top-end',
        showConfirmButton: false,
        timer: 3000
    });
}